==> power-pra-2018.11-29-any.pkg.tar.xz: usr/local/bin/power.sh <==
#!/bin/ash
v=181129 #sfs
#http://ptspts.blogspot.ru/2009/10/screen-blanking-dpms-screen-saver.html
#date +"%M %H %d" --date="@3601 1 days ago" -u ;exit
#d="`date +"%d" -d @$s -u`" #;exit
SET(){
xset s $1 $1
xset dpms $1 $1 $1 
}
[ "$1" ] && { SET $1 ;exit ; }
t1="Управление электропитанием"
#t="Управление гашением экрана при простое (DPMS)."
t="<b>Гашение экрана</b> при простое (DPMS)."

Y(){
yad --title="$t1 v.$v" \
    --text=" <big>$t1</big>" \
    --image="screen_lock" \
    --window-icon="/usr/share/pixmaps/screen_lock.svg" \
    --XXwindow-icon="lock" \
    --fixed --image-on-top --center \
    --form \
	--field=:LBL '' \
    --field="$t":LBL '' \
    --field="<small>0=не гасить. Актуально при просмотре фильмов в браузере и т.п.</small>":LBL '' \
    --field="минут:SCL" "$1"\
    --field="часов:NUM" "$2"\
    --field="сохранить это время после перезагрузки:CHK" "$3"\
    --field="запрос пароля для возобновления работы:CHK" "$ssaver"\
	--field=:LBL '' \
    --field="<b>Ждущий режим</b>":LBL '' \
    --field="запрос пароля для возобновления работы:CHK" "$suspend"\
    --field="при закрытии крышки ноутбука:CHK" "$close"\
	--field=:LBL '' \
    --field="Кнопки питания, сна, крышка!shutdown:FBTN" 'bash -c "power-acpi &"'\
    --button="Пароль"!lock!"Смена пароля пользователя системы":3 \
    --button=gtk-ok:0  \
    --button=gtk-cancel:2  
#    --XXfield="запрос пароля для возобновления работы!lock:BTN" 'bash -c "pass.sh &"'\
#    --XXfield="часов:NUM" "0!1..60!2!2" \
#    --separator='\n' 
#    | sudo passwd "$U" #>/dev/null
}

#lid="`awk -F= '/^HandleLidSwitch=/ {print $2}' /etc/systemd/logind.conf`"
#[ "$lid" ] || lid="suspend" 

#echo $lid ;exit

s="$HOME/.config/autostart/dpms.desktop"
p="/home/`sfsusr`/.config/pass.conf"
[ -f "$p" ] || printf "acpi=true\nssaver=\nsuspend=true\nclose=true\n" >"$p"
#[ -f "$p" ] || printf "ssaver=\n" >"$p"
. "$p"
#echo "susp=$suspend"

[ -f "$s" ] && f=TRUE
y="$(Y `xset -q |awk '/timeout: / {print ($2-(int($2/60/60)*60*60))/60" "int($2/60/60)}'` $f)" #|| exit
r="$?"
y="`echo $y |sed 's/^|||//' `"
echo "11 $y $r"
#[ "$r" = "2" ] && exit
case $r in
    3) chpass 
	$0 &
    ;;
    4) defaultbrowser "https://wiki.archlinux.org/index.php/Display_Power_Management_Signaling" ;;
#    2) exit  ;;
    0) 
d="`echo $y |awk -F"|" '{print int($1*60+$2*60*60)}'`"

if [ $d -gt 0  ];then
 if [ $d -lt 60 ];then
    ntf -a "Не рекомендуется автогашение экрана $d (менее минуты)" "Увеличьте..." 
    ($0 & );  exit
 fi
fi
#ntf -i " $d"
SET $d
A(){
mkdir -p "`dirname "$s"`"
echo "\
[Desktop Entry]
Type=Application
Icon=screen_resolution
Name=DPMS
Name[ru]=Время гашения экрана $d (сек.)
Comment[ru]=Управление гашением экрана при простое
Exec=`basename $0` $d 
" > "$s"
}
echo "y=$y"
XE(){ 
if [ "`which acpid`" ];then
    printf "acpi=true\nsuspend=true\nclose=true\n" >>"$p" 
else    
    echo "---systemctl enable  suspend@`sfsusr` "
    #sed -i 's/suspend=false/suspend=true/' "$p"
    echo "suspend=true" >>"$p"
    sudo systemctl enable  suspend@`sfsusr` 
fi
}
XD(){ 
if [ "`which acpid`" ];then
    sed -i 's/acpi=true//' "$p" ; sed -i 's/suspend=true//' "$p" ; sed -i 's/close=true//' "$p" 
else
    echo "---systemctl disable  suspend@`sfsusr` "
    #sed -i 's/suspend=true/suspend=false/' "$p"
    sudo systemctl disable suspend@`sfsusr` 
fi
}

[ "`echo $y |awk -F"|" '{print $3}'`" = "TRUE" ] && A || rm "$s"

sed -i 's/ssaver=true//' "$p"
if [ "`echo $y |awk -F"|" '{print $4}'`" = "TRUE" ];then
    echo "ssaver=true" >> $p 
    pidof xss-lock || xss-lock xlock &
else
    killall xss-lock
fi

#sed -i 's/close=true//' "$p"
#[ "`echo $y |awk -F"|" '{print $6}'`" = "TRUE" ] && echo "close=true" >> $p

sed -i 's/suspend=true//' "$p"
#[ "`echo $y |awk -F"|" '{print $7}'`" = "TRUE" ] && echo "suspend=true" >> $p && XE || XD
[ "`echo $y |awk -F"|" '{print $7}'`" = "TRUE" ] && XE || XD

sed -i 's/close=true//' "$p"
    sudo sed 's/^HandleLidSwitch=.*//' /etc/systemd/logind.conf
if [ "`echo $y |awk -F"|" '{print $8}'`" = "TRUE" ] ;then
    echo "close=true" >> $p 
else sudo echo "HandleLidSwitch=ignore" >> /etc/systemd/logind.conf
fi

	;;
    *) exit ;;
esac

==> power-pra-2024.02-12-any.pkg.tar.xz: usr/local/bin/power.sh <==
#!/bin/ash
v=240210 #sfs
#http://ptspts.blogspot.ru/2009/10/screen-blanking-dpms-screen-saver.html
#date +"%M %H %d" --date="@3601 1 days ago" -u ;exit
#d="`date +"%d" -d @$s -u`" #;exit
SET(){
xset s $1 $1
xset dpms $1 $1 $1 
}
[ "$1" ] && { SET $1 ;exit ; }
t1="Управление электропитанием"
#t="Управление гашением экрана при простое (DPMS)."
t="<b>Гашение экрана</b> при простое (DPMS)."

Y(){
yad --title="$t1 v.$v" \
    --text=" <big>$t1</big>" \
    --image="screen_lock" \
    --window-icon="/usr/share/pixmaps/screen_lock.svg" \
    --XXwindow-icon="lock" \
    --fixed --image-on-top --center \
    --form \
	--field=:LBL '' \
    --field="$t":LBL '' \
    --field="<small>0=не гасить. Актуально при просмотре фильмов в браузере и т.п.</small>":LBL '' \
    --field="минут:SCL" "$1"\
    --field="часов:NUM" "$2"\
    --field="сохранить это время после перезагрузки:CHK" "$3"\
    --field="запрос пароля для возобновления работы:CHK" "$ssaver"\
	--field=:LBL '' \
    --field="<b>Ждущий режим</b>":LBL '' \
    --field="запрос пароля для возобновления работы:CHK" "$suspend"\
    --field="при закрытии крышки ноутбука:CHK" "$close"\
    --field="сон вместо гашения экрана:CHK" "$ss"\
	--field=:LBL '' \
    --field="Кнопки питания, сна, крышка!shutdown:FBTN" 'bash -c "power-acpi &"'\
    --button="Пароль"!lock!"Смена пароля пользователя системы":3 \
    --button=gtk-ok:0  \
    --button=gtk-cancel:2  
#    --XXfield="запрос пароля для возобновления работы!lock:BTN" 'bash -c "pass.sh &"'\
#    --XXfield="часов:NUM" "0!1..60!2!2" \
#    --separator='\n' 
#    | sudo passwd "$U" #>/dev/null
}

#lid="`awk -F= '/^HandleLidSwitch=/ {print $2}' /etc/systemd/logind.conf`"
#[ "$lid" ] || lid="suspend" 

#echo $lid ;exit

s="$HOME/.config/autostart/dpms.desktop"
p="/home/`sfsusr`/.config/pass.conf"
[ -f "$p" ] || printf "acpi=true\nssaver=\nsuspend=true\nclose=true\nss=\n" >"$p"
#[ -f "$p" ] || printf "ssaver=\n" >"$p"
. "$p"
#echo "susp=$suspend"

[ -f "$s" ] && f=TRUE
y="$(Y `xset -q |awk '/timeout: / {print ($2-(int($2/60/60)*60*60))/60" "int($2/60/60)}'` $f)" #|| exit
r="$?"
y="`echo $y |sed 's/^|||//' `"
echo "11 $y $r"
#exit
#[ "$r" = "2" ] && exit
case $r in
    3) chpass 
	$0 &
    ;;
    4) defaultbrowser "https://wiki.archlinux.org/index.php/Display_Power_Management_Signaling" ;;
#    2) exit  ;;
    0) 
d="`echo $y |awk -F"|" '{print int($1*60+$2*60*60)}'`"

if [ $d -gt 0  ];then
 if [ $d -lt 60 ];then
    ntf -a "Не рекомендуется автогашение экрана $d (менее минуты)" "Увеличьте..." 
    ($0 & );  exit
 fi
fi
#ntf -i " $d"
SET $d
A(){
mkdir -p "`dirname "$s"`"
echo "\
[Desktop Entry]
Type=Application
Icon=screen_resolution
Name=DPMS
Name[ru]=Время гашения экрана $d (сек.)
Comment[ru]=Управление гашением экрана при простое
Exec=`basename $0` $d 
" > "$s"
}
echo "y=$y"
XE(){ 
if [ "`which acpid`" ];then
    printf "acpi=true\nsuspend=true\nclose=true\n" >>"$p" 
else    
    echo "---systemctl enable  suspend@`sfsusr` "
    #sed -i 's/suspend=false/suspend=true/' "$p"
    echo "suspend=true" >>"$p"
    sudo systemctl enable  suspend@`sfsusr` 
fi
}
XD(){ 
if [ "`which acpid`" ];then
    sed -i 's/acpi=true//' "$p" ; sed -i 's/suspend=true//' "$p" ; sed -i 's/close=true//' "$p" 
else
    echo "---systemctl disable  suspend@`sfsusr` "
    #sed -i 's/suspend=true/suspend=false/' "$p"
    sudo systemctl disable suspend@`sfsusr` 
fi
}

[ "`echo $y |awk -F"|" '{print $3}'`" = "TRUE" ] && A || rm "$s"

sed -i '/^$/d' "$p"
sed -i 's/ssaver=.*//' "$p"
if [ "`echo $y |awk -F"|" '{print $4}'`" = "TRUE" ];then
    echo "ssaver=true" >> $p 
#    pidof xss-lock || xss-lock xlock &
#else
#    killall xss-lock
fi

#sed -i 's/close=true//' "$p"
#[ "`echo $y |awk -F"|" '{print $6}'`" = "TRUE" ] && echo "close=true" >> $p

sed -i 's/suspend=.*//' "$p"
#[ "`echo $y |awk -F"|" '{print $7}'`" = "TRUE" ] && echo "suspend=true" >> $p && XE || XD
[ "`echo $y |awk -F"|" '{print $7}'`" = "TRUE" ] && XE || XD

sed -i 's/close=.*//' "$p"
    sudo sed 's/^HandleLidSwitch=.*//' /etc/systemd/logind.conf
if [ "`echo $y |awk -F"|" '{print $8}'`" = "TRUE" ] ;then
    echo "close=true" >> $p 
else sudo echo "HandleLidSwitch=ignore" >> /etc/systemd/logind.conf
fi

#[ "$ss" ] && 
sed -i 's/ss=.*//' "$p" 
[ "`echo $y |awk -F"|" '{print $9}'`" = "TRUE" ] && echo "ss=true" >>"$p" || echo "ss=" >>"$p"

. "$p"
killall xss-lock
[ "$ssaver$ss" ] && xss-lock xlock-s &
	;;
    *) exit ;;
esac
